@@ -344,7 +344,8 @@ Bool mono_is_linear(const Mono* mono)
 {
    assert(mono_is_valid(mono));
 
-   return mono->count == 1 && mono->fun == MFUN_NONE;
+   /* ??? Effect not fully testet */
+   return mono->count == 1 && (mono->fun == MFUN_NONE || mono->fun == MFUN_TRUE || mono->fun == MFUN_FALSE);
 }
 
 int mono_get_degree(const Mono* mono)
