@@ -1,4 +1,4 @@
-/* $Id: term.h,v 1.6 2011/10/25 08:18:02 bzfkocht Exp $ */
+/* $Id: term.h,v 1.8 2012/07/29 15:09:30 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: term.h                                                        */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2011 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2012 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -46,7 +46,7 @@ typedef struct term              Term;
 /*lint -sem(        term_new, 1n > 0, @p == 1) */
 extern Term*        term_new(int size);
 /*lint -sem(        term_add_elem, 1p == 1 && 2p == 1 && 3p == 1) */
-extern void         term_add_elem(Term* term, const Entry* entry, const Numb* coeff);
+extern void         term_add_elem(Term* term, const Entry* entry, const Numb* coeff, MFun mfun);
 #if 0 /* ??? not used */
 /*lint -sem(        term_mul_elem, 1p == 1 && 2p == 1 && 3p == 1) */
 extern void         term_mul_elem(Term* term, const Entry* entry, const Numb* coeff);
@@ -95,6 +95,8 @@ extern Bound*       term_get_upper_bound(const Term* term);
 extern Bool         term_is_all_integer(const Term* term);
 /*lint -sem(        term_is_linear, 1p == 1) */
 extern Bool         term_is_linear(const Term* term);
+/*lint -sem(        term_is_polynomial, 1p == 1) */
+extern Bool         term_is_polynomial(const Term* term);
 /*lint -sem(        term_get_degree, 1p == 1) */
 extern int          term_get_degree(const Term* term);
 /*lint -sem(        term_make_conditional, 1p == 1 && 2p == 1, @p == 1) */
